@@ -33,11 +33,10 @@ module Network.Http.Inconvenience (
     HttpClientError(..),
 
         -- for testing
-    splitURI
+    splitURI,
+    parseURL
 ) where
 
-#include "config.h"
-
 import Blaze.ByteString.Builder (Builder)
 import qualified Blaze.ByteString.Builder as Builder (fromByteString,
                                                       fromWord8, toByteString)
@@ -60,7 +59,8 @@ import Data.Word (Word16)
 import GHC.Exts
 import GHC.Word (Word8 (..))
 import Network.URI (URI (..), URIAuth (..), isAbsoluteURI,
-                    parseRelativeReference, parseURI, uriToString)
+                    parseRelativeReference,
+                    parseURI, escapeURIString, isUnescapedInURI, uriToString)
 import OpenSSL (withOpenSSL)
 import OpenSSL.Session (SSLContext)
 import qualified OpenSSL.Session as SSL
@@ -77,11 +77,12 @@ import Network.Http.Connection
 import Network.Http.RequestBuilder
 import Network.Http.Types
 
-#if defined __LINUX__ || defined __FREEBSD__
+-- (see also http://downloads.haskell.org/~ghc/8.4.2/docs/html/users_guide/phases.html#standard-cpp-macros
+-- for a list of predefined CPP macros provided by GHC and/or Cabal; see also the cabal user's guide)
+#if defined(linux_HOST_OS) || defined(freebsd_HOST_OS)
 import System.Directory (doesDirectoryExist)
 #endif
 
-
 type URL = ByteString
 
 ------------------------------------------------------------------------------
@@ -238,14 +239,14 @@ baselineContextSSL :: IO SSLContext
 baselineContextSSL = withOpenSSL $ do
     ctx <- SSL.context
     SSL.contextSetDefaultCiphers ctx
-#if defined __MACOSX__
+#if defined(darwin_HOST_OS)
     SSL.contextSetVerificationMode ctx SSL.VerifyNone
-#elif defined __WINDOWS__
+#elif defined(mingw32_HOST_OS)
     SSL.contextSetVerificationMode ctx SSL.VerifyNone
-#elif defined __FREEBSD__
+#elif defined(freebsd_HOST_OS)
     SSL.contextSetCAFile ctx "/usr/local/etc/ssl/cert.pem"
     SSL.contextSetVerificationMode ctx $ SSL.VerifyPeer True True Nothing
-#elif defined __OPENBSD__
+#elif defined(openbsd_HOST_OS)
     SSL.contextSetCAFile ctx "/etc/ssl/cert.pem"
     SSL.contextSetVerificationMode ctx $ SSL.VerifyPeer True True Nothing
 #else
@@ -266,7 +267,7 @@ parseURL r' =
         Just u  -> u
         Nothing -> error ("Can't parse URI " ++ r)
   where
-    r = T.unpack $ T.decodeUtf8 r'
+    r = escapeURIString isUnescapedInURI $ T.unpack $ T.decodeUtf8 r'
 
 ------------------------------------------------------------------------------
 
